# Gizoogle translator for Python

A little utility for translating/textilizing things into gangster.

Written based on https://github.com/mfkp/gizoogle.

Be respectful with usage, and please do not use in production.

Requires bs4, requests, and lxml.

## Installation

gizoogle-py can be installed through pip:

```sh
$ pip install gizoogle_py
```

## Usage

```sh
$ python -m gizoogle -t "hello world"
wassup ghetto
$ python -m gizoogle -l "http://reddit.com"
http://www.gizoogle.net/tranzizzle.php?search=http%3A%2F%2Freddit.com
```

